Namespaces
----------

.. autoclass:: socketio.ClientNamespace
   :members:
   :inherited-members:

.. autoclass:: socketio.Namespace
   :members:
   :inherited-members:

.. autoclass:: socketio.AsyncClientNamespace
   :members:
   :inherited-members:

.. autoclass:: socketio.AsyncNamespace
   :members:
   :inherited-members:

